package main

import (
	"bufio"
	"flag"
	"fmt"
	"github.com/oz123/gupta"
	"log"
	"os"
	"time"
)

func readFirstLine(rd *bufio.Reader, f *os.File) string {
	line, err := rd.ReadString('\n')
	if err != nil {
		log.Fatalf("could not read /proc/stat, error: %v", err)
	}
	rd.Reset(f)
	f.Seek(0, 0)
	return line
}

func readProcStatLines(freq int) (string, string) {
	var line, newline string
	f, err := os.Open("/proc/stat")
	if err != nil {
		log.Fatalf("could not read /proc/stat, error: %v", err)
	}
	defer f.Close()
	rd := bufio.NewReader(f)
	line = readFirstLine(rd, f)
	time.Sleep(time.Duration(freq) * time.Second)
	newline = readFirstLine(rd, f)
	return line, newline
}

func main() {
	var freq int
	var partition, netInterface string
	var load, memory, cpu bool

	flag.IntVar(&freq, "frequency", 5, "Frequency of polling in secods")
	flag.IntVar(&freq, "f", 5, "Frequency of polling in secods")
	flag.BoolVar(&memory, "m", false, "Poll memory")
	flag.BoolVar(&load, "l", false, "Poll load")
	flag.BoolVar(&cpu, "c", false, "poll CPU usage")
	flag.StringVar(&partition, "p", "", "Poll disk usage (partition)")
	flag.StringVar(&netInterface, "n", "", "Network usage (interface)")

	flag.Parse()

	fmt.Println(gupta.Hello())

	for true {
		line, lineNew := readProcStatLines(freq)
		cpustat := gupta.NewCPUStat(line, lineNew)
		fmt.Printf("CPU usage %.2f%%\n", cpustat.CPUUsage())
	}
}
